@@ -185,6 +185,8 @@ class TopicView(RedirectToLoginMixin, generic.ListView):
         self.topic.views += 1
         self.topic.save()
         qs = self.topic.posts.all().select_related('user')
+        if defaults.PYBB_PROFILE_RELATED_NAME:
+            qs = qs.select_related('user__%s' % defaults.PYBB_PROFILE_RELATED_NAME)
         if not perms.may_moderate_topic(self.request.user, self.topic):
             qs = perms.filter_posts(self.request.user, qs)
         return qs
@@ -598,7 +600,7 @@ class TopicPollVoteView(generic.UpdateView):
         return super(ModelFormMixin, self).form_valid(form)
 
     def form_invalid(self, form):
-        return self.object.get_absolute_url()
+        return redirect(self.object)
 
     def get_success_url(self):
         return self.object.get_absolute_url()
